View source: R/cumulative-coefficient.R
| compute_cumu_diff | R Documentation |
CIs are calculated by sampling coefficients from their posterior and
calculating the cumulative hazard difference nsim times. The CI
are obtained by the 2.5\
compute_cumu_diff(
d1,
d2,
model,
alpha = 0.05,
nsim = 100L,
time_var = "tend",
interval_length = "intlen"
)
d1 |
A data set used as |
d2 |
See |
model |
A model object for which a predict method is implemented which
returns the design matrix (e.g., |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.