R/cumulative-coefficient.R
cumulative_coefficient.RdThese functions are designed to extract (or mimic) the cumulative coefficients usually used in additive hazards models (Aalen model) to depict (time-varying) covariate effects. For PAMMs, these are the differences between the cumulative hazard rates where all covariates except one have the identical values. For a numeric covariate of interest, this calculates \(\Lambda(t|x+1) - \Lambda(t|x)\). For non-numeric covariates the cumulative hazard of the reference level is subtracted from the cumulative hazards evaluated at all non reference levels. Standard errors are calculated using the delta method.
get_cumu_coef(model, data = NULL, terms, ...)
# S3 method for class 'gam'
get_cumu_coef(
model,
data,
terms,
time_var = "tend",
interval_length = "intlen",
...
)
# S3 method for class 'aalen'
get_cumu_coef(model, data = NULL, terms, ci = TRUE, ...)
# S3 method for class 'cox.aalen'
get_cumu_coef(model, data = NULL, terms, ci = TRUE, ...)Object from which to extract cumulative coefficients.
Additional data if necessary.
A character vector of variables for which the cumulative coefficient should be calculated.
Further arguments passed to methods.
Name of the evaluation time variable in data. Defaults to
"tend".
Name of the interval-length variable in data.
Defaults to "intlen".
Logical. Indicates if confidence intervals should be returned as well.