| dplyr_verbs | R Documentation |
dplyr verbs for ped-objectsSee dplyr documentation of the respective functions for
description and examples.
## S3 method for class 'ped'
arrange(.data, ...)
## S3 method for class 'ped'
group_by(.data, ..., .add = FALSE)
## S3 method for class 'ped'
ungroup(x, ...)
## S3 method for class 'ped'
distinct(.data, ..., .keep_all = FALSE)
## S3 method for class 'ped'
filter(.data, ...)
## S3 method for class 'ped'
sample_n(tbl, size, replace = FALSE, weight = NULL, .env = NULL, ...)
## S3 method for class 'ped'
sample_frac(tbl, size = 1, replace = FALSE, weight = NULL, .env = NULL, ...)
## S3 method for class 'ped'
slice(.data, ...)
## S3 method for class 'ped'
select(.data, ...)
## S3 method for class 'ped'
mutate(.data, ...)
## S3 method for class 'ped'
rename(.data, ...)
## S3 method for class 'ped'
summarise(.data, ...)
## S3 method for class 'ped'
summarize(.data, ...)
## S3 method for class 'ped'
transmute(.data, ...)
## S3 method for class 'ped'
inner_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
## S3 method for class 'ped'
full_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
relationship = NULL
)
## S3 method for class 'ped'
left_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
## S3 method for class 'ped'
right_join(
x,
y,
by = NULL,
copy = FALSE,
suffix = c(".x", ".y"),
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
.data |
an object of class |
... |
see |
x |
an object of class |
tbl |
an object of class |
size |
< |
replace |
Sample with or without replacement? |
weight |
< |
.env |
DEPRECATED. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
copy |
If |
suffix |
If there are non-joined duplicate variables in |
keep |
Should the join keys from both
|
na_matches |
Should two
|
multiple |
Handling of rows in
|
unmatched |
How should unmatched keys that would result in dropped rows be handled?
|
relationship |
Handling of the expected relationship between the keys of
|
a modified ped object (except for do)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.