Learn R Programming

pammtools (version 0.1.14)

get_cumu_coef_baseline: Extract cumulative coefficients (cumulative hazard differences)

Description

These functions are designed to extract (or mimic) the cumulative coefficients usually used in additive hazards models (Aalen model) to depict (time-varying) covariate effects. For PAMMs, these are the differences between the cumulative hazard rates where all covariates except one have the identical values. For a numeric covariate of interest, this calculates \(\Lambda(t|x+1) - \Lambda(t|x)\). For non-numeric covariates the cumulative hazard of the reference level is subtracted from the cumulative hazards evaluated at all non reference levels. Standard errors are calculated using the delta method.

Usage

get_cumu_coef_baseline(data, model, ...)

Arguments

data

Additional data if necessary.

model

Object from which to extract cumulative coefficients.

...

Further arguments passed to methods.