Learn R Programming

pammtools (version 0.1.9)

gg_partial: Visualize effect estimates for specific covariate combinations

Description

Depending on the plot function and input, creates either a 1-dimensional slices, bivariate surface or (1D) cumulative effect.

Usage

gg_partial(data, model, term, ..., reference = NULL, ci = TRUE)

gg_partial_ll(data, model, term, ..., reference = NULL, ci = FALSE, time_var = "tend")

get_partial_ll(data, model, term, ..., reference = NULL, ci = FALSE, time_var = "tend")

Arguments

data

Data used to fit the model.

model

A suitable model object which will be used to estimate the partial effect of term.

term

A character string indicating the model term for which partial effects should be plotted.

...

Covariate specifications (expressions) that will be evaluated by looking for variables in x (or data). Must be of the form z = f(z) where z is a variable in the data set x and f a known function that can be usefully applied to z. See examples below.

reference

If specified, should be a list with covariate value pairs, e.g. list(x1 = 1, x2=50). The calculated partial effect will be relative to an observation specified in reference.

ci

Logical. Indicates if confidence intervals for the term of interest should be calculated/plotted. Defaults to TRUE.

time_var

The name of the variable that was used in model to represent follow-up time.