View source: R/add-functions.R
| hazard_ci | R Documentation |
Adds a hazard column and, for ci_type "default"/
"delta", se/ci_lower/ci_upper, using the
linear-predictor triplet make_X/get_coefs/get_Vp. This is
the analytic CI path (also used to evaluate reference hazard ratios and
type = "link"). Simulation-based CIs instead use the
get_hazard + sim_hazard primitives.
hazard_ci(
object,
newdata,
reference = NULL,
ci = TRUE,
type = c("response", "link"),
ci_type = c("default", "delta", "sim"),
time_var = NULL,
se_mult = 2,
...
)
object |
a fitted |
newdata |
A data frame or list containing the values of the model covariates at which predictions
are required. If this is not provided then predictions corresponding to the
original data are returned. If |
reference |
A data frame with number of rows equal to |
ci |
|
type |
Either |
ci_type |
The method by which standard errors/confidence intervals
will be calculated. Default transforms the linear predictor at
respective intervals. |
time_var |
Name of the variable used for the baseline hazard. Defaults
to |
se_mult |
Factor by which standard errors are multiplied for calculating the confidence intervals. |
... |
Further arguments passed to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.