smooth_term_rows: Turn a single mgcv smooth into zero or more curve...

View source: R/get-terms.R

smooth_term_rowsR Documentation

Turn a single mgcv smooth into zero or more curve specifications

Description

Turn a single mgcv smooth into zero or more curve specifications

Usage

smooth_term_rows(s, data)

Arguments

s

A single smooth object from fit$smooth.

data

A data frame containing the variables used to fit the model.


pammtools documentation built on Aug. 27, 2026, 1:08 a.m.