Add (cumulative) hazard based on the provided data set and model.
If ci=TRUE confidence intervals are also added. Their width can
be controlled via the se_mult argument. This is a wrapper around
predict.gam.
add_hazard(newdata, object, type = c("response", "link"), ci = TRUE,
se_mult = 2, ci_type = c("default", "delta", "sim"),
overwrite = FALSE, time_var = NULL, ...)add_cumu_hazard(newdata, object, ci = TRUE, se_mult = 2,
overwrite = FALSE, time_var = NULL, interval_length = "intlen",
...)
A data frame or list containing the values of the model covariates at which predictions
are required. If this is not provided then predictions corresponding to the
original data are returned. If newdata is provided then
it should contain all the variables needed for prediction: a
warning is generated if not. See details for use with link{linear.functional.terms}.
a fitted gam object as produced by gam().
When this has the value "link" (default) the linear predictor (possibly with
associated standard errors) is returned. When type="terms" each component of the
linear predictor is returned seperately (possibly with standard errors): this includes
parametric model components, followed by each smooth component, but excludes
any offset and any intercept. type="iterms" is the same, except that any standard errors
returned for smooth components will include the uncertainty about the intercept/overall mean. When
type="response" predictions
on the scale of the response are returned (possibly with approximate
standard errors). When type="lpmatrix" then a matrix is returned
which yields the values of the linear predictor (minus any offset) when
postmultiplied by the
parameter vector (in this case se.fit is ignored). The latter
option is most useful for getting variance estimates for quantities derived from
the model: for example integrated quantities, or derivatives of smooths. A
linear predictor matrix can also be used to implement approximate prediction
outside R (see example code, below).
Logical indicating whether to include confidence intervals. Defaults
to TRUE
Factor by which standard errors are multiplied for calculating the confidence intervals.
The method by which standard errors/confidence intervals
will be calculated. Default transforms the linear predictor at
respective intervals. "delta" calculates CIs based on the standard
error calculated by the Delta method. "sim" draws the
property of interest from its posterior based on the normal distribution of
the estimated coefficients. CIs are given by respective quantiles.
Should hazard columns be overwritten if already present in
the data set? Defaults to FALSE. If TRUE, columns with names
c("hazard", "se", "lower", "upper") will be overwritten.
Name of the variable used for the baseline hazard. If
not given, defaults to "tend" for gam fits, else
"interval". The latter is assumed to be a factor, the former
numeric.
Further arguments passed to predict.gam and
get_hazard
The variable in newdata containing the interval lengths.
Can be either bare unquoted variable name or character. Defaults to "intlen".
# NOT RUN {
ped <- tumor[1:50,] %>% as_ped(Surv(days, status)~ age)
pam <- mgcv::gam(ped_status ~ s(tend)+age, data = ped, family=poisson(), offset=offset)
ped_info(ped) %>% add_hazard(pam, type="link")
ped_info(ped) %>% add_hazard(pam, type = "response")
ped_info(ped) %>% add_cumu_hazard(pam)
# }
Run the code above in your browser using DataLab