CIs are calculated by sampling coefficients from their posterior and
calculating the cumulative hazard difference nsim times. The CI
are obtained by the 2.5\
compute_cumu_diff(
d1,
d2,
model,
alpha = 0.05,
nsim = 100L,
time_var = "tend",
interval_length = "intlen"
)A data set used as newdata in make_X
See d1
A model object for which a predict method is implemented which
returns the design matrix (e.g., mgcv::gam).