Learn R Programming

pammtools (version 0.8.1)

get_Vp: Extract the (Bayesian) covariance matrix of the model coefficients

Description

Returns the covariance matrix that matches the coefficients returned by get_coefs. For mgcv models this is the Bayesian posterior covariance matrix object$Vp, for scam models the covariance matrix of the re-parametrized coefficients object$Vp.t and vcov(object) otherwise.

Usage

get_Vp(object, ...)

# S3 method for default get_Vp(object, ...)

# S3 method for gam get_Vp(object, ...)

# S3 method for scam get_Vp(object, ...)

Arguments

object

A fitted model object.

...

Further arguments passed to methods.