Returns the coefficient vector coefs such that make_X(object, newdata) %*% coefs yields the linear predictor. For most models this is simply coef(object). For scam models, however, coef() returns the coefficients on the underlying unconstrained scale, while the linear predictor is calculated from the re-parametrized (partially exponentiated) coefficients object$coefficients.t.

get_coefs(object, ...)

# Default S3 method
get_coefs(object, ...)

# S3 method for class 'scam'
get_coefs(object, ...)

Arguments

object

A fitted model object.

...

Further arguments passed to methods.