These functions are designed to extract (or mimic) the cumulative coefficients usually used in additive hazards models (Aalen model) to depict (time-varying) covariate effects. For PAMMs, these are the differences between the cumulative hazard rates where all covariates except one have the identical values. For a numeric covariate of interest, this calculates \(\Lambda(t|x+1) - \Lambda(t|x)\). For non-numeric covariates the cumulative hazard of the reference level is subtracted from the cumulative hazards evaluated at all non reference levels. Standard errors are calculated using the delta method.
get_cumu_coef_baseline(data, model, ...)Additional data if necessary.
Object from which to extract cumulative coefficients.
Further arguments passed to methods.