Calculate cumulative hazard
get_cumu_hazard(
newdata,
object,
ci = TRUE,
ci_type = c("default", "delta", "sim"),
time_var = NULL,
se_mult = 2,
interval_length = "intlen",
nsim = 100L,
...
)A data frame or list containing the values of the model covariates at which predictions
are required. If this is not provided then predictions corresponding to the
original data are returned. If newdata is provided then
it should contain all the variables needed for prediction: a
warning is generated if not. See details for use with link{linear.functional.terms}.
a fitted gam object as produced by gam().
logical. Indicates if confidence intervals should be
calculated. Defaults to TRUE.
The method by which standard errors/confidence intervals
will be calculated. Default transforms the linear predictor at
respective intervals. "delta" calculates CIs based on the standard
error calculated by the Delta method. "sim" draws the
property of interest from its posterior based on the normal distribution of
the estimated coefficients. See here
for details and empirical evaluation. For ci_type = "sim", interval
bounds are empirical quantiles (type 6, see quantile)
of nsim posterior draws (default nsim = 100L, passed via
...). Type-6 quantiles avoid the systematic inward bias that the
quantile default (type 7) exhibits for small
nsim, but at the default nsim = 100 the bounds are estimated
from few tail draws and thus noisy; increase nsim (e.g., to 500 or
more) for more stable interval bounds. Very small nsim
(nsim < 2 / alpha - 1, i.e., below 39 for alpha = 0.05)
cannot achieve the nominal level at all.
Name of the variable used for the baseline hazard. Defaults
to "tend".
Factor by which standard errors are multiplied for calculating the confidence intervals.
The variable in newdata containing the interval lengths.
Can be either bare unquoted variable name or character. Defaults to "intlen".
Total number of pooled posterior draws used for the interval.
Further arguments passed to predict.gam and
get_hazard