| get_term | R Documentation |
Extract the partial effect of a single smooth curve
get_term(data, fit, spec, n = 100, conf_level = 0.95, ...)
data |
A data frame containing variables used to fit the model. The first row is used as the basis for all covariates other than the one being varied (their values are irrelevant for the term-wise contribution). |
fit |
A fitted object of class |
spec |
A single-row tibble (one row of |
n |
Number of points at which to evaluate the smooth over the range of its covariate. |
conf_level |
The confidence level for the pointwise confidence interval. |
... |
Further arguments (currently unused). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.