Extract the partial effect of a single smooth curve
get_term(data, fit, spec, n = 100, conf_level = 0.95, ...)A data frame containing variables used to fit the model. The first row is used as the basis for all covariates other than the one being varied (their values are irrelevant for the term-wise contribution).
A fitted object of class gam.
A single-row tibble (one row of get_smooth_terms)
describing the curve to extract.
Number of points at which to evaluate the smooth over the range of its covariate.
The confidence level for the pointwise confidence interval.
Further arguments (currently unused).