| get_term_legacy | R Documentation |
$smooth componentFallback used for fits such as coxph that support
predict(type = "terms") but expose no mgcv smooth metadata. Matching is
anchored to the variable name (exact, or as a parenthesised argument such as
pspline(karno)) rather than an unanchored substring.
get_term_legacy(data, fit, term, n = 100, conf_level = 0.95, ...)
data |
A data frame containing variables used to fit the model. The first row is used as the basis for all covariates other than the one being varied (their values are irrelevant for the term-wise contribution). |
fit |
A fitted object of class |
term |
A character string naming the model term/variable. |
n |
Number of points at which to evaluate the smooth over the range of its covariate. |
conf_level |
The confidence level for the pointwise confidence interval. |
... |
Further arguments (currently unused). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.