Learn R Programming

pammtools (version 0.8.1)

pamm: Fit a piece-wise exponential additive model

Description

A thin wrapper around gam, however, some arguments are prespecified: family=poisson() and offset=data$offset. These two can not be overwritten. In many cases it will also be advisable to set method="REML".

Usage

pamm(formula, data = list(), ..., trafo_args = NULL, engine = "gam")

is.pamm(x)

# S3 method for pamm print(x, ...)

# S3 method for pamm summary(object, ...)

# S3 method for pamm plot(x, ...)

Arguments

formula

A GAM formula, or a list of formulae (see formula.gam and also gam.models). These are exactly like the formula for a GLM except that smooth terms, s, te, ti and t2, can be added to the right hand side to specify that the linear predictor depends on smooth functions of predictors (or linear functionals of these).

data

A data frame or list containing the model response variable and covariates required by the formula. By default the variables are taken from environment(formula): typically the environment from which gam is called.

...

Further arguments passed to engine.

trafo_args

Deprecated. A named list passed to as_ped for inline data transformation. Convert your data with as_ped() before calling pamm() instead.

engine

Character name of the function that will be called to fit the model. The intended entries are "gam" or "bam" (both from package mgcv) or "scam" (from package scam, for shape-constrained PAMMs, e.g. monotone baseline hazards).

x

Any R object.

object

An object of class pamm as returned by pamm.

See Also

Examples

Run this code
ped <- tumor[1:100, ] %>%
 as_ped(Surv(days, status) ~ complications, cut = seq(0, 3000, by = 50))
pam <- pamm(ped_status ~ s(tend) + complications, data = ped)
summary(pam)
## Deprecated: trafo_args inline transformation (use as_ped() instead)
# ped2 <- as_ped(tumor[1:100, ], Surv(days, status) ~ complications)
# pamm(ped_status ~ s(tend) + complications, data = ped2)

Run the code above in your browser using DataLab