Computes interval lengths from the sorted unique values of the time variable
in newdata. This is used by add_* functions that need intlen for cumulative
calculations. If tstart is not available, the first interval length is
taken as the first sorted time value (implicitly assuming a 0-origin time
scale).
reconstruct_intlen(newdata, time_var = "tend", interval_length = "intlen")The input data frame with an intlen column added.
A data frame with a time column (default tend).
Character name of the time variable. Defaults to
"tend".
Character name of the interval-length column to create.