Learn R Programming

pammtools (version 0.2.2)

riskset_info: Extract risk set information for each interval.

Description

The columns ped_riskset, ped_events, ped_censored provide the size of the risk set at the beginning of each interval as well as the number of events and censorings that occurred in the interval, respectively.

Usage

riskset_info(ped)

Arguments

ped

An object of class ped as returned by as_ped.

Value

A data frame with one row for each interval in ped.

See Also

int_info, sample_info

Examples

Run this code
# NOT RUN {
ped <- tumor[1:4,] %>% as_ped(Surv(days, status)~ .)
riskset_info(ped)
# }

Run the code above in your browser using DataLab