| smooth_term_rows | R Documentation |
Turn a single mgcv smooth into zero or more curve specifications
smooth_term_rows(s, data)
s |
A single smooth object from |
data |
A data frame containing the variables used to fit the model. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.