smooth_term_rows: Turn a single mgcv smooth into zero or more curve specifications
Description
Turn a single mgcv smooth into zero or more curve specifications
Usage
smooth_term_rows(s, data)
Arguments
- s
A single smooth object from fit$smooth.
- data
A data frame containing the variables used to fit the model.